@@ -18,7 +18,7 @@
 #include "k3bjobhandler.h"
 #include "k3b_export.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 
 
 namespace K3b {
@@ -33,7 +33,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        SimpleJobHandler( QObject* parent = 0 );
+        explicit SimpleJobHandler( QObject* parent = 0 );
         ~SimpleJobHandler();
 
         /*
