@@ -18,7 +18,7 @@
 
 #include "k3bdevicetypes.h"
 #include "k3b_export.h"
-#include <QtCore/QThread>
+#include <QThread>
 
 
 namespace K3b {
@@ -37,7 +37,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        Thread( ThreadJob* parent = 0 );
+        explicit Thread( ThreadJob* parent = 0 );
         ~Thread();
 
         void ensureDone();
