@@ -19,8 +19,8 @@
 
 #include "k3bjob.h"
 
-#include <QtCore/QList>
-#include <QtCore/QProcess>
+#include <QList>
+#include <QProcess>
 
 namespace K3b {
     class Process;
@@ -30,7 +30,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        AudioNormalizeJob( JobHandler*, QObject* parent = 0 );
+        explicit AudioNormalizeJob( JobHandler*, QObject* parent = 0 );
         ~AudioNormalizeJob();
 
     public Q_SLOTS:
