@@ -25,7 +25,6 @@
 #include "k3bdevicehandler.h"
 #include "k3btoc.h"
 #include "k3btrack.h"
-#include "k3bdevicehandler.h"
 #include "k3bexternalbinmanager.h"
 #include "k3bcdrecordwriter.h"
 #include "k3bcdrdaowriter.h"
@@ -42,13 +41,13 @@
 #include <KIOCore/KIO/Global>
 #include <KIOCore/KIO/Job>
 
-#include <QtCore/QDataStream>
-#include <QtCore/QDateTime>
-#include <QtCore/QDebug>
-#include <QtCore/QFile>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QTemporaryFile>
+#include <QDataStream>
+#include <QDateTime>
+#include <QDebug>
+#include <QFile>
+#include <QString>
+#include <QStringList>
+#include <QTemporaryFile>
 
 
 
