@@ -15,7 +15,7 @@
 #ifndef _K3B_MEDIUM_DELEGATE_H_
 #define _K3B_MEDIUM_DELEGATE_H_
 
-#include <QtWidgets/QStyledItemDelegate>
+#include <QStyledItemDelegate>
 
 namespace K3b {
     class MediumDelegate : public QStyledItemDelegate
@@ -23,7 +23,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        MediumDelegate( QObject* parent );
+        explicit MediumDelegate( QObject* parent );
         ~MediumDelegate();
 
         // FIXME: move this elsewhere
