@@ -16,7 +16,7 @@
 #ifndef K3BSPLASH_H
 #define K3BSPLASH_H
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 class QLabel;
 class QMouseEvent;
@@ -30,7 +30,7 @@ class Splash : public QWidget
     Q_OBJECT
 
 public:
-    Splash( QWidget* parent = 0 );
+    explicit Splash( QWidget* parent = 0 );
     ~Splash();
 
 public Q_SLOTS:
