@@ -15,11 +15,11 @@
 #ifndef _K3B_THEME_MANAGER_H_
 #define _K3B_THEME_MANAGER_H_
 
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QMap>
-#include <QtGui/QColor>
-#include <QtGui/QPixmap>
+#include <QObject>
+#include <QString>
+#include <QMap>
+#include <QColor>
+#include <QPixmap>
 
 #include <KConfigCore/KConfigGroup>
 
@@ -29,7 +29,7 @@ namespace K3b {
     {
     public:
         Theme();
-        Theme( QString name );
+        explicit Theme( QString name );
 
         QColor backgroundColor() const;
         QColor foregroundColor() const;
@@ -113,7 +113,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        ThemeManager( QObject* parent = 0 );
+        explicit ThemeManager( QObject* parent = 0 );
         ~ThemeManager();
 
         QList<Theme*> themes() const;
