@@ -16,7 +16,7 @@
 #define _K3B_URL_NAVIGATOR_H_
 
 #include <KIOFileWidgets/KUrlNavigator>
-#include <QtCore/QUrl>
+#include <QUrl>
 
 namespace K3b {
     namespace Device {
@@ -28,7 +28,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        UrlNavigator( KFilePlacesModel* model, QWidget* parent = 0 );
+        explicit UrlNavigator( KFilePlacesModel* model, QWidget* parent = 0 );
         ~UrlNavigator();
 
     public Q_SLOTS:
