@@ -16,7 +16,7 @@
 #ifndef K3B_CDDB_OPTIONTAB_H
 #define K3B_CDDB_OPTIONTAB_H
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 class KCModule;
 
@@ -26,7 +26,7 @@ class CddbOptionTab : public QWidget
     Q_OBJECT
 
 public:
-    CddbOptionTab( QWidget* parent = 0 );
+    explicit CddbOptionTab( QWidget* parent = 0 );
     ~CddbOptionTab();
 
 public Q_SLOTS:
