@@ -16,7 +16,7 @@
 #ifndef K3B_EXTERNALBIN_OPTIONTAB_H
 #define K3B_EXTERNALBIN_OPTIONTAB_H
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 
 namespace K3b {
@@ -29,7 +29,7 @@ class ExternalBinOptionTab : public QWidget
 Q_OBJECT
 
  public:
-  ExternalBinOptionTab( ExternalBinManager* manager, QWidget* = 0 );
+  explicit ExternalBinOptionTab( ExternalBinManager* manager, QWidget* = 0 );
   ~ExternalBinOptionTab();
 
   void readSettings();
