@@ -17,8 +17,8 @@
 
 #include "k3bmsf.h"
 
-#include <QtCore/QList>
-#include <QtWidgets/QDialog>
+#include <QList>
+#include <QDialog>
 
 namespace K3b {
     class AudioTrack;
@@ -32,7 +32,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        AudioTrackDialog( const QList<AudioTrack*>&, QWidget *parent=0);
+        explicit AudioTrackDialog( const QList<AudioTrack*>&, QWidget *parent=0);
         ~AudioTrackDialog();
 
     protected Q_SLOTS:
