@@ -15,7 +15,7 @@
 #ifndef K3BDATAPROJECTSORTPROXYMODEL_H
 #define K3BDATAPROJECTSORTPROXYMODEL_H
 
-#include <QtCore/QSortFilterProxyModel>
+#include <QSortFilterProxyModel>
 
 
 namespace K3b {
@@ -28,7 +28,7 @@ namespace K3b {
     class DataProjectSortProxyModel : public QSortFilterProxyModel
     {
     public:
-        DataProjectSortProxyModel( QObject* parent = 0 );
+        explicit DataProjectSortProxyModel( QObject* parent = 0 );
 
     protected:
         virtual bool lessThan(const QModelIndex& left, const QModelIndex& right) const;
