@@ -18,11 +18,11 @@
 #include "k3bvalidators.h"
 
 #include <KCompletion/KLineEdit>
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
-#include <QtCore/QEvent>
-#include <QtWidgets/QHBoxLayout>
-#include <QtWidgets/QLabel>
+#include <QEvent>
+#include <QHBoxLayout>
+#include <QLabel>
 
 namespace K3b {
 
