@@ -16,7 +16,7 @@
 #ifndef _K3B_AUDIO_TRACK_MODEL_H_
 #define _K3B_AUDIO_TRACK_MODEL_H_
 
-#include <QtCore/QAbstractItemModel>
+#include <QAbstractItemModel>
 
 namespace KCDDB {
     class CDInfo;
@@ -30,7 +30,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        AudioTrackModel( QObject* parent = 0 );
+        explicit AudioTrackModel( QObject* parent = 0 );
         ~AudioTrackModel();
 
         enum Columns {
